==> DateTime-Locale-1.16.tar.gz: DateTime-Locale-1.16/share/zh-Hant.pl <==
{
  am_pm_abbreviated => [
    "\N{U+4e0a}\N{U+5348}",
    "\N{U+4e0b}\N{U+5348}"
  ],
  available_formats => {
    E => "ccc",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d E",
    Ehm => "E ah:mm",
    Ehms => "E ah:mm:ss",
    Gy => "Gy\N{U+5e74}",
    GyMMM => "Gy\N{U+5e74}M\N{U+6708}",
    GyMMMEd => "Gy\N{U+5e74}M\N{U+6708}d\N{U+65e5} E",
    GyMMMd => "Gy\N{U+5e74}M\N{U+6708}d\N{U+65e5}",
    H => "H\N{U+6642}",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss [v]",
    Hmv => "HH:mm [v]",
    M => "M\N{U+6708}",
    MEd => "M/d\N{U+ff08}E\N{U+ff09}",
    MMM => "LLL",
    MMMEd => "M\N{U+6708}d\N{U+65e5} E",
    "MMMMW-count-other" => "MMM\N{U+7684}\N{U+7b2c}W\N{U+9031}",
    MMMMd => "M\N{U+6708}d\N{U+65e5}",
    MMMd => "M\N{U+6708}d\N{U+65e5}",
    MMdd => "MM/dd",
    Md => "M/d",
    d => "d\N{U+65e5}",
    h => "ah\N{U+6642}",
    hm => "ah:mm",
    hms => "ah:mm:ss",
    hmsv => "ah:mm:ss [v]",
    hmv => "ah:mm [v]",
    ms => "mm:ss",
    y => "y\N{U+5e74}",
    yM => "y/M",
    yMEd => "y/M/d\N{U+ff08}E\N{U+ff09}",
    yMM => "y/MM",
    yMMM => "y\N{U+5e74}M\N{U+6708}",
    yMMMEd => "y\N{U+5e74}M\N{U+6708}d\N{U+65e5} E",
    yMMMM => "y\N{U+5e74}M\N{U+6708}",
    yMMMd => "y\N{U+5e74}M\N{U+6708}d\N{U+65e5}",
    yMd => "y/M/d",
    yQQQ => "y\N{U+5e74}QQQ",
    yQQQQ => "y\N{U+5e74}QQQQ",
    "yw-count-other" => "y\N{U+5e74}\N{U+7684}\N{U+7b2c}w\N{U+9031}"
  },
  code => "zh-Hant",
  date_format_full => "y\N{U+5e74}M\N{U+6708}d\N{U+65e5} EEEE",
  date_format_long => "y\N{U+5e74}M\N{U+6708}d\N{U+65e5}",
  date_format_medium => "y\N{U+5e74}M\N{U+6708}d\N{U+65e5}",
  date_format_short => "y/M/d",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "\N{U+9031}\N{U+4e00}",
    "\N{U+9031}\N{U+4e8c}",
    "\N{U+9031}\N{U+4e09}",
    "\N{U+9031}\N{U+56db}",
    "\N{U+9031}\N{U+4e94}",
    "\N{U+9031}\N{U+516d}",
    "\N{U+9031}\N{U+65e5}"
  ],
  day_format_narrow => [
    "\N{U+4e00}",
    "\N{U+4e8c}",
    "\N{U+4e09}",
    "\N{U+56db}",
    "\N{U+4e94}",
    "\N{U+516d}",
    "\N{U+65e5}"
  ],
  day_format_wide => [
    "\N{U+661f}\N{U+671f}\N{U+4e00}",
    "\N{U+661f}\N{U+671f}\N{U+4e8c}",
    "\N{U+661f}\N{U+671f}\N{U+4e09}",
    "\N{U+661f}\N{U+671f}\N{U+56db}",
    "\N{U+661f}\N{U+671f}\N{U+4e94}",
    "\N{U+661f}\N{U+671f}\N{U+516d}",
    "\N{U+661f}\N{U+671f}\N{U+65e5}"
  ],
  day_stand_alone_abbreviated => [
    "\N{U+9031}\N{U+4e00}",
    "\N{U+9031}\N{U+4e8c}",
    "\N{U+9031}\N{U+4e09}",
    "\N{U+9031}\N{U+56db}",
    "\N{U+9031}\N{U+4e94}",
    "\N{U+9031}\N{U+516d}",
    "\N{U+9031}\N{U+65e5}"
  ],
  day_stand_alone_narrow => [
    "\N{U+4e00}",
    "\N{U+4e8c}",
    "\N{U+4e09}",
    "\N{U+56db}",
    "\N{U+4e94}",
    "\N{U+516d}",
    "\N{U+65e5}"
  ],
  day_stand_alone_wide => [
    "\N{U+661f}\N{U+671f}\N{U+4e00}",
    "\N{U+661f}\N{U+671f}\N{U+4e8c}",
    "\N{U+661f}\N{U+671f}\N{U+4e09}",
    "\N{U+661f}\N{U+671f}\N{U+56db}",
    "\N{U+661f}\N{U+671f}\N{U+4e94}",
    "\N{U+661f}\N{U+671f}\N{U+516d}",
    "\N{U+661f}\N{U+671f}\N{U+65e5}"
  ],
  era_abbreviated => [
    "\N{U+897f}\N{U+5143}\N{U+524d}",
    "\N{U+897f}\N{U+5143}"
  ],
  era_narrow => [
    "\N{U+897f}\N{U+5143}\N{U+524d}",
    "\N{U+897f}\N{U+5143}"
  ],
  era_wide => [
    "\N{U+897f}\N{U+5143}\N{U+524d}",
    "\N{U+897f}\N{U+5143}"
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Chinese",
  month_format_abbreviated => [
    "1\N{U+6708}",
    "2\N{U+6708}",
    "3\N{U+6708}",
    "4\N{U+6708}",
    "5\N{U+6708}",
    "6\N{U+6708}",
    "7\N{U+6708}",
    "8\N{U+6708}",
    "9\N{U+6708}",
    "10\N{U+6708}",
    "11\N{U+6708}",
    "12\N{U+6708}"
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12
  ],
  month_format_wide => [
    "1\N{U+6708}",
    "2\N{U+6708}",
    "3\N{U+6708}",
    "4\N{U+6708}",
    "5\N{U+6708}",
    "6\N{U+6708}",
    "7\N{U+6708}",
    "8\N{U+6708}",
    "9\N{U+6708}",
    "10\N{U+6708}",
    "11\N{U+6708}",
    "12\N{U+6708}"
  ],
  month_stand_alone_abbreviated => [
    "1\N{U+6708}",
    "2\N{U+6708}",
    "3\N{U+6708}",
    "4\N{U+6708}",
    "5\N{U+6708}",
    "6\N{U+6708}",
    "7\N{U+6708}",
    "8\N{U+6708}",
    "9\N{U+6708}",
    "10\N{U+6708}",
    "11\N{U+6708}",
    "12\N{U+6708}"
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12
  ],
  month_stand_alone_wide => [
    "1\N{U+6708}",
    "2\N{U+6708}",
    "3\N{U+6708}",
    "4\N{U+6708}",
    "5\N{U+6708}",
    "6\N{U+6708}",
    "7\N{U+6708}",
    "8\N{U+6708}",
    "9\N{U+6708}",
    "10\N{U+6708}",
    "11\N{U+6708}",
    "12\N{U+6708}"
  ],
  name => "Chinese Traditional",
  native_language => "\N{U+4e2d}\N{U+6587}",
  native_name => "\N{U+4e2d}\N{U+6587} \N{U+7e41}\N{U+9ad4}",
  native_script => "\N{U+7e41}\N{U+9ad4}",
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "1\N{U+5b63}",
    "2\N{U+5b63}",
    "3\N{U+5b63}",
    "4\N{U+5b63}"
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_format_wide => [
    "\N{U+7b2c}1\N{U+5b63}",
    "\N{U+7b2c}2\N{U+5b63}",
    "\N{U+7b2c}3\N{U+5b63}",
    "\N{U+7b2c}4\N{U+5b63}"
  ],
  quarter_stand_alone_abbreviated => [
    "1\N{U+5b63}",
    "2\N{U+5b63}",
    "3\N{U+5b63}",
    "4\N{U+5b63}"
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_stand_alone_wide => [
    "\N{U+7b2c}1\N{U+5b63}",
    "\N{U+7b2c}2\N{U+5b63}",
    "\N{U+7b2c}3\N{U+5b63}",
    "\N{U+7b2c}4\N{U+5b63}"
  ],
  script => "Traditional",
  territory => undef,
  time_format_full => "ah:mm:ss [zzzz]",
  time_format_long => "ah:mm:ss [z]",
  time_format_medium => "ah:mm:ss",
  time_format_short => "ah:mm",
  variant => undef,
  version => 31
}

==> DateTime-Locale-1.35.tar.gz: DateTime-Locale-1.35/share/zh-Hant.pl <==
{
  am_pm_abbreviated => [
    "\N{U+4e0a}\N{U+5348}",
    "\N{U+4e0b}\N{U+5348}",
  ],
  available_formats => {
    Bh => "Bh\N{U+6642}",
    Bhm => "Bh:mm",
    Bhms => "Bh:mm:ss",
    E => "ccc",
    EBhm => "E Bh:mm",
    EBhms => "E Bh:mm:ss",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d E",
    Ehm => "E Bh:mm",
    Ehms => "E Bh:mm:ss",
    Gy => "Gy\N{U+5e74}",
    GyMMM => "Gy\N{U+5e74}M\N{U+6708}",
    GyMMMEd => "Gy\N{U+5e74}M\N{U+6708}d\N{U+65e5} E",
    GyMMMd => "Gy\N{U+5e74}M\N{U+6708}d\N{U+65e5}",
    GyMd => "G y/M/d",
    H => "H\N{U+6642}",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss [v]",
    Hmv => "HH:mm [v]",
    M => "M\N{U+6708}",
    MEd => "M/d\N{U+ff08}E\N{U+ff09}",
    MMM => "LLL",
    MMMEd => "M\N{U+6708}d\N{U+65e5} E",
    "MMMMW-count-other" => "MMMM\N{U+7684}\N{U+7b2c}W\N{U+9031}",
    MMMMd => "M\N{U+6708}d\N{U+65e5}",
    MMMd => "M\N{U+6708}d\N{U+65e5}",
    MMdd => "MM/dd",
    Md => "M/d",
    d => "d\N{U+65e5}",
    h => "Bh\N{U+6642}",
    hm => "Bh:mm",
    hms => "Bh:mm:ss",
    hmsv => "Bh:mm:ss [v]",
    hmv => "Bh:mm [v]",
    ms => "mm:ss",
    y => "y\N{U+5e74}",
    yM => "y/M",
    yMEEEEd => "y\N{U+5e74}M\N{U+6708}d\N{U+65e5} EEEE",
    yMEd => "y/M/d\N{U+ff08}E\N{U+ff09}",
    yMM => "y/MM",
    yMMM => "y\N{U+5e74}M\N{U+6708}",
    yMMMEd => "y\N{U+5e74}M\N{U+6708}d\N{U+65e5} E",
    yMMMM => "y\N{U+5e74}M\N{U+6708}",
    yMMMd => "y\N{U+5e74}M\N{U+6708}d\N{U+65e5}",
    yMd => "y/M/d",
    yQQQ => "y\N{U+5e74}QQQ",
    yQQQQ => "y\N{U+5e74}QQQQ",
    "yw-count-other" => "Y\N{U+5e74}\N{U+7684}\N{U+7b2c}w\N{U+9031}",
  },
  code => "zh-Hant",
  date_format_full => "y\N{U+5e74}M\N{U+6708}d\N{U+65e5} EEEE",
  date_format_long => "y\N{U+5e74}M\N{U+6708}d\N{U+65e5}",
  date_format_medium => "y\N{U+5e74}M\N{U+6708}d\N{U+65e5}",
  date_format_short => "y/M/d",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "\N{U+9031}\N{U+4e00}",
    "\N{U+9031}\N{U+4e8c}",
    "\N{U+9031}\N{U+4e09}",
    "\N{U+9031}\N{U+56db}",
    "\N{U+9031}\N{U+4e94}",
    "\N{U+9031}\N{U+516d}",
    "\N{U+9031}\N{U+65e5}",
  ],
  day_format_narrow => [
    "\N{U+4e00}",
    "\N{U+4e8c}",
    "\N{U+4e09}",
    "\N{U+56db}",
    "\N{U+4e94}",
    "\N{U+516d}",
    "\N{U+65e5}",
  ],
  day_format_wide => [
    "\N{U+661f}\N{U+671f}\N{U+4e00}",
    "\N{U+661f}\N{U+671f}\N{U+4e8c}",
    "\N{U+661f}\N{U+671f}\N{U+4e09}",
    "\N{U+661f}\N{U+671f}\N{U+56db}",
    "\N{U+661f}\N{U+671f}\N{U+4e94}",
    "\N{U+661f}\N{U+671f}\N{U+516d}",
    "\N{U+661f}\N{U+671f}\N{U+65e5}",
  ],
  day_stand_alone_abbreviated => [
    "\N{U+9031}\N{U+4e00}",
    "\N{U+9031}\N{U+4e8c}",
    "\N{U+9031}\N{U+4e09}",
    "\N{U+9031}\N{U+56db}",
    "\N{U+9031}\N{U+4e94}",
    "\N{U+9031}\N{U+516d}",
    "\N{U+9031}\N{U+65e5}",
  ],
  day_stand_alone_narrow => [
    "\N{U+4e00}",
    "\N{U+4e8c}",
    "\N{U+4e09}",
    "\N{U+56db}",
    "\N{U+4e94}",
    "\N{U+516d}",
    "\N{U+65e5}",
  ],
  day_stand_alone_wide => [
    "\N{U+661f}\N{U+671f}\N{U+4e00}",
    "\N{U+661f}\N{U+671f}\N{U+4e8c}",
    "\N{U+661f}\N{U+671f}\N{U+4e09}",
    "\N{U+661f}\N{U+671f}\N{U+56db}",
    "\N{U+661f}\N{U+671f}\N{U+4e94}",
    "\N{U+661f}\N{U+671f}\N{U+516d}",
    "\N{U+661f}\N{U+671f}\N{U+65e5}",
  ],
  era_abbreviated => [
    "\N{U+897f}\N{U+5143}\N{U+524d}",
    "\N{U+897f}\N{U+5143}",
  ],
  era_narrow => [
    "\N{U+897f}\N{U+5143}\N{U+524d}",
    "\N{U+897f}\N{U+5143}",
  ],
  era_wide => [
    "\N{U+897f}\N{U+5143}\N{U+524d}",
    "\N{U+897f}\N{U+5143}",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Chinese",
  month_format_abbreviated => [
    "1\N{U+6708}",
    "2\N{U+6708}",
    "3\N{U+6708}",
    "4\N{U+6708}",
    "5\N{U+6708}",
    "6\N{U+6708}",
    "7\N{U+6708}",
    "8\N{U+6708}",
    "9\N{U+6708}",
    "10\N{U+6708}",
    "11\N{U+6708}",
    "12\N{U+6708}",
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_format_wide => [
    "1\N{U+6708}",
    "2\N{U+6708}",
    "3\N{U+6708}",
    "4\N{U+6708}",
    "5\N{U+6708}",
    "6\N{U+6708}",
    "7\N{U+6708}",
    "8\N{U+6708}",
    "9\N{U+6708}",
    "10\N{U+6708}",
    "11\N{U+6708}",
    "12\N{U+6708}",
  ],
  month_stand_alone_abbreviated => [
    "1\N{U+6708}",
    "2\N{U+6708}",
    "3\N{U+6708}",
    "4\N{U+6708}",
    "5\N{U+6708}",
    "6\N{U+6708}",
    "7\N{U+6708}",
    "8\N{U+6708}",
    "9\N{U+6708}",
    "10\N{U+6708}",
    "11\N{U+6708}",
    "12\N{U+6708}",
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_stand_alone_wide => [
    "1\N{U+6708}",
    "2\N{U+6708}",
    "3\N{U+6708}",
    "4\N{U+6708}",
    "5\N{U+6708}",
    "6\N{U+6708}",
    "7\N{U+6708}",
    "8\N{U+6708}",
    "9\N{U+6708}",
    "10\N{U+6708}",
    "11\N{U+6708}",
    "12\N{U+6708}",
  ],
  name => "Chinese Traditional",
  native_language => "\N{U+4e2d}\N{U+6587}",
  native_name => "\N{U+4e2d}\N{U+6587} \N{U+7e41}\N{U+9ad4}",
  native_script => "\N{U+7e41}\N{U+9ad4}",
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "\N{U+7b2c}1\N{U+5b63}",
    "\N{U+7b2c}2\N{U+5b63}",
    "\N{U+7b2c}3\N{U+5b63}",
    "\N{U+7b2c}4\N{U+5b63}",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "\N{U+7b2c}1\N{U+5b63}",
    "\N{U+7b2c}2\N{U+5b63}",
    "\N{U+7b2c}3\N{U+5b63}",
    "\N{U+7b2c}4\N{U+5b63}",
  ],
  quarter_stand_alone_abbreviated => [
    "\N{U+7b2c}1\N{U+5b63}",
    "\N{U+7b2c}2\N{U+5b63}",
    "\N{U+7b2c}3\N{U+5b63}",
    "\N{U+7b2c}4\N{U+5b63}",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "\N{U+7b2c}1\N{U+5b63}",
    "\N{U+7b2c}2\N{U+5b63}",
    "\N{U+7b2c}3\N{U+5b63}",
    "\N{U+7b2c}4\N{U+5b63}",
  ],
  script => "Traditional",
  territory => undef,
  time_format_full => "Bh:mm:ss [zzzz]",
  time_format_long => "Bh:mm:ss [z]",
  time_format_medium => "Bh:mm:ss",
  time_format_short => "Bh:mm",
  variant => undef,
  version => 41,
}
